# CICD

> Interesting souls have no place~
> Interesting souls have no place~
> Interesting souls have no place~

deploy to cloud ☁️ serverless 

---
## Deploy to Cloudflare ☁️ (KISS)
more frontend app
- pages
- workers
### tools
- wrangler

## Deploy to AWS ☁
- api Gateway + lambda
  - [fastapi-daily-chat-bot](https://github.com/ai-bot-pro/chat-bot/tree/feat/deploy/deploy/aws/fastapi-daily-chat-bot)
### tools
- cdk
- sam

## Deploy to GCP ☁
### tools
- gcloud

## Deploy to OCI ☁

## Deploy to Azure ☁

## Deploy to Alibaba Cloud ☁

## Deploy Tools (provider cloud tools)
- terraform (Terraform)
- sls (Serverless)
- use [skypilot](https://skypilot.readthedocs.io/en/latest/docs/index.html) to deploy model

---

## Deploy to cerebrium (KISS)
provider: AWS
- [fastapi-daily-chat-bot](https://github.com/ai-bot-pro/achatbot/tree/main/deploy/cerebrium/fastapi-daily-chat-bot)
### tools
- cerebrium

## Deploy to leptonai (KISS)
- [fastapi-daily-chat-bot](https://github.com/ai-bot-pro/achatbot/tree/main/deploy/leptonai/fastapi-daily-chat-bot)

### tools
- lep photon `pip install leptonai`
---

## Deploy to modal (KISS)
provider: AWS, GCP, OCI
- [fastapi_webrtc_audio_bot_serve](https://github.com/ai-bot-pro/achatbot/tree/main/deploy/modal/src/fastapi_webrtc_audio_bot_serve.py)

### tools
- modal `pip install modal`
---


# references
- 